
.. _api:

API Reference
/////////////////


Fields
-------

- :py:class:`~data.core.fieldlist.Field`
- :py:class:`~data.core.fieldlist.FieldList`

Metadata
----------

- :py:class:`~data.core.metadata.Metadata`
- :py:class:`~data.core.metadata.RawMetadata`
- :py:class:`~data.readers.grib.metadata.GribMetadata`

GRIB
-------

- :py:class:`~data.readers.grib.index.GribFieldList`
- :py:class:`~data.readers.grib.codes.GribField`

BUFR
-----

- :py:class:`~data.readers.bufr.bufr.BUFRList`
- :py:class:`~data.readers.bufr.bufr.BUFRMessage`

Other
--------

- :py:class:`~data.utils.bbox.BoundingBox`
